Crate mzdata_bindata

Crate mzdata_bindata 

The DataArray implementation for data buffer manipulation used for, amongst other things, mapping numeric data to and from optionally compressed little endian base-64 byte arrays with as few data copies as possible, algebraically.

Also covers the ArrayType enum that covers the standardized array flavors telling us which dimension an array describes, BinaryArrayMap collections of (ArrayType, DataArray), and traits for converting to and from BinaryArrayMap based upon the set of available ArrayType. This includes a generalization for BinaryArrayMap3D when ion mobility is available.

Modules

utils

Structs

BinaryArrayMap
A collection of DataArrays that are identified by name.
BinaryArrayMap3D
Represent a set of BinaryArrayMap that has been split across the ion mobility dimension.
DataArray
Represents a data array that holds a byte buffer that may be compressed, base64 encoded, or raw little endian bytes, and provides views of those bytes as a small range of supported types.
DataArraySlice
Represent a slice of a DataArray that manages offsets and decoding automatically.

Enums

ArrayRetrievalError
A high level set of failure modes that an operation to retrieve a typed memory buffer from a BinaryArrayMap might encounter. May also be used to represented conversion during reading or writing.
ArrayType
The kinds of data arrays found in mass spectrometry data files governed by the PSI-MS controlled vocabulary.
ArraysAvailable
BinaryCompressionType
The range of compression and encoding states that a raw byte buffer might be in during different stages of decoding. Other than Decoded, these states may or may not include intermediate base64 encoding.
BinaryDataArrayType
The canonical primitive data types found in MS data file formats supported by the PSI-MS controlled vocabulary

Traits

BuildArrayMap3DFrom
BuildArrayMapFrom
BuildFromArrayMap
BuildFromArrayMap3D
ByteArrayView
ByteArrayViewMut

Functions

as_bytes
delta_decoding
delta_encoding
linear_prediction_decoding
linear_prediction_encoding
to_bytes
Convert the values in data into an owned buffer of little-endian bytes
vec_as_bytes

Type Aliases

Bytes