ArrayType

Enum ArrayType 

pub enum ArrayType {
Show 26 variants Unknown, MZArray, IntensityArray, ChargeArray, SignalToNoiseArray, TimeArray, WavelengthArray, IonMobilityArray, MeanIonMobilityArray, MeanDriftTimeArray, MeanInverseReducedIonMobilityArray, RawIonMobilityArray, RawDriftTimeArray, RawInverseReducedIonMobilityArray, DeconvolutedIonMobilityArray, DeconvolutedDriftTimeArray, DeconvolutedInverseReducedIonMobilityArray, ScanningQuadrupolePositionLowerBoundMZ, ScanningQuadrupolePositionUpperBoundMZ, IndexArray, BaselineArray, ResolutionArray, PressureArray, TemperatureArray, FlowRateArray, NonStandardDataArray { name: Box<String>, },
}
The kinds of data arrays found in mass spectrometry data files governed by the PSI-MS controlled vocabulary.

Variants



Unknown



MZArray



IntensityArray



ChargeArray



SignalToNoiseArray



TimeArray



WavelengthArray



IonMobilityArray



MeanIonMobilityArray



MeanDriftTimeArray



MeanInverseReducedIonMobilityArray



RawIonMobilityArray



RawDriftTimeArray



RawInverseReducedIonMobilityArray



DeconvolutedIonMobilityArray



DeconvolutedDriftTimeArray



DeconvolutedInverseReducedIonMobilityArray



ScanningQuadrupolePositionLowerBoundMZ



ScanningQuadrupolePositionUpperBoundMZ



IndexArray



BaselineArray



ResolutionArray



PressureArray



TemperatureArray



FlowRateArray



NonStandardDataArray

Fields

name: Box<String>

Implementations

Source

impl ArrayType

pub const fn preferred_dtype(&self) -> BinaryDataArrayType

Get the data type that the array is compatible with in the mzdata type expectations.

By default, the m/z array is encoded using Float64, the charge state array is encoded using Int32, and all other arrays are encoded using Float32.

pub const fn as_mean_ion_mobility(&self) -> Option<ArrayType>

Convert an ion mobility array to its mean variant

pub const fn as_raw_ion_mobility(&self) -> Option<ArrayType>

Convert an ion mobility array to its raw variant

pub const fn as_deconvoluted_ion_mobility(&self) -> Option<ArrayType>

Convert an ion mobility array to its deconvoluted variant

pub fn nonstandard<S: ToString>(name: S) -> ArrayType

Create a ArrayType::NonStandardDataArray with the provided name.

pub const fn is_ion_mobility(&self) -> bool

Test if the the array describes an ion mobility quantity.

pub fn as_param(&self, unit: Option<Unit>) -> Param

Create a Param for this array type.

If a unit is provided, that unit will be specified, otherwise a default unit may be used instead.

pub const fn as_param_const(&self) -> ParamCow<'static>

Create a ParamCow for this array type in a const context using the default unit.

NOTE: If this is a Self::NonStandardDataArray, this function will panic as this variant requires allocation.

pub const fn as_param_with_unit_const(&self, unit: Unit) -> ParamCow<'static>

Create a ParamCow for this array type in a const context using the provided unit.

NOTE: If this is a Self::NonStandardDataArray, this function will panic as this variant requires allocation.

pub fn from_accession(x: CURIE) -> Option<Self>

Translate from CURIE to an ArrayType