BinaryCompressionType

Enum BinaryCompressionType 

pub enum BinaryCompressionType {
Show 18 variants NoCompression, Zlib, NumpressLinear, NumpressSLOF, NumpressPIC, NumpressLinearZlib, NumpressSLOFZlib, NumpressPICZlib, LinearPrediction, DeltaPrediction, Decoded, Zstd, ShuffleZstd, DeltaShuffleZstd, ZstdDict, NumpressLinearZstd, NumpressSLOFZstd, NumpressPICZstd,
}
The range of compression and encoding states that a raw byte buffer might be in during different stages of decoding. Other than Decoded, these states may or may not include intermediate base64 encoding.

Variants



NoCompression



Zlib



NumpressLinear



NumpressSLOF



NumpressPIC



NumpressLinearZlib



NumpressSLOFZlib



NumpressPICZlib



LinearPrediction



DeltaPrediction



Decoded



Zstd



ShuffleZstd



DeltaShuffleZstd



ZstdDict



NumpressLinearZstd



NumpressSLOFZstd



NumpressPICZstd

Implementations

Source

impl BinaryCompressionType

pub const COMPRESSION_METHODS: &[Self]

pub fn unsupported_msg(&self, context: Option<&str>) -> String

Generate a user-understandable message about why a compression conversion operation failed

pub const fn is_endian_aware(&self) -> bool

Check if the compressor handles endianess during decoding. Otherwise the data needs to be byteswapped to little endianess on big endian systems before use

pub const fn accession(&self) -> Option<u32>

pub fn from_accession(accession: CURIE) -> Option<Self>

Convert a CURIE into a compression method, if one exists.

pub const fn as_param(&self) -> Option<ParamCow<'static>>

Convert the compression type to a ParamCow.

Most compression methods have a controlled vocabulary term.