The DataArray implementation for data buffer manipulation used for, amongst other things,
mapping numeric data to and from optionally compressed little endian base-64 byte arrays with
as few data copies as possible, algebraically.
Also covers the ArrayType enum that covers the standardized array flavors telling us which
dimension an array describes, BinaryArrayMap collections of (ArrayType, DataArray), and
traits for converting to and from BinaryArrayMap based upon the set of available ArrayType.
This includes a generalization for BinaryArrayMap3D when ion mobility is available.
Modules
Structs
- Binary
Array Map - A collection of
DataArrays that are identified by name. - Binary
Array Map3D - Represent a set of
BinaryArrayMapthat has been split across the ion mobility dimension. - Data
Array - Represents a data array that holds a byte buffer that may be compressed, base64 encoded, or raw little endian bytes, and provides views of those bytes as a small range of supported types.
- Data
Array Slice - Represent a slice of a
DataArraythat manages offsets and decoding automatically.
Enums
- Array
Retrieval Error - A high level set of failure modes that an operation to retrieve a typed memory buffer
from a
BinaryArrayMapmight encounter. May also be used to represented conversion during reading or writing. - Array
Type - The kinds of data arrays found in mass spectrometry data files governed by the PSI-MS controlled vocabulary.
- Arrays
Available - Binary
Compression Type - The range of compression and encoding states that a raw byte buffer
might be in during different stages of decoding. Other than
Decoded, these states may or may not include intermediate base64 encoding. - Binary
Data Array Type - The canonical primitive data types found in MS data file formats supported by the PSI-MS controlled vocabulary
Traits
- Build
Array Map3D From - Build
Array MapFrom - Build
From Array Map - Build
From Array Map3D - Byte
Array View - Byte
Array View Mut
Functions
- as_
bytes - delta_
decoding - delta_
encoding - linear_
prediction_ decoding - linear_
prediction_ encoding - to_
bytes - Convert the values in
datainto an owned buffer of little-endian bytes - vec_
as_ bytes